/*++

Copyright (c) 2022 ELMOS Co., Ltd.

Module Name:
	AWG10K2.h
Abstract:
	AWG-10K2 API library definitions
Revision History:
	22/08/05	Created.

--*/

#ifndef AWG10K2_H
#define AWG10K2_H

#ifdef AWG10K2_EXPORTS_
#define AWG10K2_API __declspec(dllexport)
#else
#define AWG10K2_API __declspec(dllimport)
#endif

//
// Return code
//
enum {
	AWG10K2_OK,
   	AWG10K2_INVALID_ID,
    AWG10K2_DEVICE_NOT_FOUND,
    AWG10K2_DEVICE_NOT_OPENED,
	AWG10K2_INVALID_PARAMETER,
	AWG10K2_MEMORY_ERROR,
	AWG10K2_COMMUNICATION_ERROR,
	AWG10K2_EXECUTION_ERROR,
	AWG10K2_OTHER_ERROR
};

//
// Constants
//

// Control Mode
#define	AWG10K2_CONTROL_MODE_REMOTE		0	// [g(PC)
#define	AWG10K2_CONTROL_MODE_TRIGGER	1	// OgK[

// Output Mode
#define	AWG10K2_OUTPUT_MODE_CONTINUE	0	// A
#define	AWG10K2_OUTPUT_MODE_REPEAT		1	// JԂ

// Trigger Type
#define	AWG10K2_TRIGGER_TYPE_RISING		0	// GbW
#define	AWG10K2_TRIGGER_TYPE_FALLING	1	// GbW

// Status
#define	AWG10K2_STATUS_NO_DATA	0	// g`o͒~(g`f[^ݒ)
#define	AWG10K2_STATUS_READY	1	// g`o͒~(g`f[^ݒ)
#define	AWG10K2_STATUS_RUNNING	2	// g`o͒

#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
AWG10K2_API int WINAPI AWG10K2_GetNumberOfDevices (int *Number);
AWG10K2_API int WINAPI AWG10K2_GetSerialNumber (int Index, int *SerialNumber);
AWG10K2_API int WINAPI AWG10K2_Open (BYTE *ID);
AWG10K2_API int WINAPI AWG10K2_OpenBySerialNumber (int SerialNumber, BYTE *ID);
AWG10K2_API int WINAPI AWG10K2_Close (BYTE ID);
AWG10K2_API int WINAPI AWG10K2_SetFile (BYTE ID, const char *FilePath);
AWG10K2_API int WINAPI AWG10K2_SetParametersAndWaveData (BYTE ID, BYTE ControlMode, BYTE OutputMode, int RepeatCount, BYTE TriggerType, int SamplingRate, int SamplingCount, double *WaveData);
AWG10K2_API int WINAPI AWG10K2_Start (BYTE ID);
AWG10K2_API int WINAPI AWG10K2_Stop (BYTE ID);
AWG10K2_API int WINAPI AWG10K2_GetStatus (BYTE ID, BYTE *Status);
AWG10K2_API int WINAPI AWG10K2_OutputPort (BYTE ID, BYTE Port);
AWG10K2_API int WINAPI AWG10K2_InputPort (BYTE ID, BYTE *Port);

#ifdef __cplusplus
}
#endif

#endif  /* AWG10K2_H */
